@@ -1,9 +1,9 @@
 #ifdef USE_ARDUINO
 
 #include "i2c_bus_arduino.h"
-#include "esphome/core/log.h"
-#include "esphome/core/helpers.h"
 #include "esphome/core/application.h"
+#include "esphome/core/helpers.h"
+#include "esphome/core/log.h"
 #include <Arduino.h>
 #include <cstring>
 
@@ -13,6 +13,7 @@ namespace i2c {
 static const char *const TAG = "i2c.arduino";
 
 void ArduinoI2CBus::setup() {
+  ESP_LOGCONFIG(TAG, "Running setup");
   recover_();
 
 #if defined(USE_ESP32)
@@ -39,7 +40,7 @@ void ArduinoI2CBus::setup() {
 
   this->initialized_ = true;
   if (this->scan_) {
-    ESP_LOGV(TAG, "Scanning i2c bus for active devices...");
+    ESP_LOGV(TAG, "Scanning bus for active devices");
     this->i2c_scan_();
   }
 }
@@ -69,9 +70,11 @@ void ArduinoI2CBus::set_pins_and_clock_() {
 
 void ArduinoI2CBus::dump_config() {
   ESP_LOGCONFIG(TAG, "I2C Bus:");
-  ESP_LOGCONFIG(TAG, "  SDA Pin: GPIO%u", this->sda_pin_);
-  ESP_LOGCONFIG(TAG, "  SCL Pin: GPIO%u", this->scl_pin_);
-  ESP_LOGCONFIG(TAG, "  Frequency: %u Hz", this->frequency_);
+  ESP_LOGCONFIG(TAG,
+                "  SDA Pin: GPIO%u\n"
+                "  SCL Pin: GPIO%u\n"
+                "  Frequency: %u Hz",
+                this->sda_pin_, this->scl_pin_, this->frequency_);
   if (timeout_ > 0) {
 #if defined(USE_ESP32)
     ESP_LOGCONFIG(TAG, "  Timeout: %u ms", this->timeout_ / 1000);
@@ -93,13 +96,13 @@ void ArduinoI2CBus::dump_config() {
       break;
   }
   if (this->scan_) {
-    ESP_LOGI(TAG, "Results from i2c bus scan:");
+    ESP_LOGI(TAG, "Results from bus scan:");
     if (scan_results_.empty()) {
-      ESP_LOGI(TAG, "Found no i2c devices!");
+      ESP_LOGI(TAG, "Found no devices");
     } else {
       for (const auto &s : scan_results_) {
         if (s.second) {
-          ESP_LOGI(TAG, "Found i2c device at address 0x%02X", s.first);
+          ESP_LOGI(TAG, "Found device at address 0x%02X", s.first);
         } else {
           ESP_LOGE(TAG, "Unknown error at address 0x%02X", s.first);
         }
@@ -215,7 +218,7 @@ ErrorCode ArduinoI2CBus::writev(uint8_t address, WriteBuffer *buffers, size_t cn
 /// https://www.nxp.com/docs/en/user-guide/UM10204.pdf
 /// https://www.analog.com/media/en/technical-documentation/application-notes/54305147357414AN686_0.pdf
 void ArduinoI2CBus::recover_() {
-  ESP_LOGI(TAG, "Performing I2C bus recovery");
+  ESP_LOGI(TAG, "Performing bus recovery");
 
   // For the upcoming operations, target for a 100kHz toggle frequency.
   // This is the maximum frequency for I2C running in standard-mode.
@@ -231,7 +234,7 @@ void ArduinoI2CBus::recover_() {
   // line. In that case, the I2C bus cannot be recovered.
   delayMicroseconds(half_period_usec);
   if (digitalRead(scl_pin_) == LOW) {  // NOLINT
-    ESP_LOGE(TAG, "Recovery failed: SCL is held LOW on the I2C bus");
+    ESP_LOGE(TAG, "Recovery failed: SCL is held LOW on the bus");
     recovery_result_ = RECOVERY_FAILED_SCL_LOW;
     return;
   }
