@@ -235,7 +235,7 @@ std::string WebServer::get_config_json() {
 }
 
 void WebServer::setup() {
-  ESP_LOGCONFIG(TAG, "Setting up web server...");
+  ESP_LOGCONFIG(TAG, "Running setup");
   this->setup_controller(this->include_internal_);
   this->base_->init();
 
@@ -282,8 +282,10 @@ void WebServer::loop() {
   this->events_.loop();
 }
 void WebServer::dump_config() {
-  ESP_LOGCONFIG(TAG, "Web Server:");
-  ESP_LOGCONFIG(TAG, "  Address: %s:%u", network::get_use_address().c_str(), this->base_->get_port());
+  ESP_LOGCONFIG(TAG,
+                "Web Server:\n"
+                "  Address: %s:%u",
+                network::get_use_address().c_str(), this->base_->get_port());
 }
 float WebServer::get_setup_priority() const { return setup_priority::WIFI - 1.0f; }
 
